.. currentmodule:: rimseval.interfacer

==========
Interfacer
==========

Functions to talk to settings, calibratinos, GUIs, etc.

------------------------------
:func:`read_lion_eval_calfile`
------------------------------

.. autofunction:: read_lion_eval_calfile

---------------------
:func:`load_cal_file`
---------------------

.. autofunction:: load_cal_file

---------------------
:func:`save_cal_file`
---------------------

.. autofunction:: save_cal_file
